.. module:: wwdtm.scorekeeper

*******************
Module: scorekeeper
*******************

This module provides objects used to retrieve scorekeepers, scorekeeper
information and scorekeeper details from a copy of the Wait Wait Don't Tell Me!
Stats database.

.. contents:: Contents
    :depth: 1
    :local:
    :backlinks: none

Scorekeeper
===========

.. autoclass:: wwdtm.scorekeeper.Scorekeeper
    :members:
    :inherited-members:

ScorekeeperAppearances
======================

.. autoclass:: wwdtm.scorekeeper.ScorekeeperAppearances
    :members:
    :inherited-members:

ScorekeeperUtility
==================

.. autoclass:: wwdtm.scorekeeper.ScorekeeperUtility
    :members:
    :inherited-members:
